-----------------------------------------------------------------
--FCOGuildBankStackSplit.lua
--Author: Baertram
--v0.0.5
--[[
Splits your stacks at the guild bank]]
------------------------------------------------------------------

--Many thanks to Harven for his addon Stack Split Slider which helped me very much with the dialog's window!!!
--You'll find some of his sourcecode in here so his enhanced stack split window will be used, if activated, too.
--I did only copy his source code to provide the compatibility with his addon and I do not claim his source code
--as mine!
local addonVars = {}
addonVars.gAddonName			= "FCOGuildBankStackSplit"
addonVars.addonNameMenu			= "FCO Guild Bank Stack Split"
addonVars.addonNameMenuDisplay	= "|c00FF00FCO |cFFFF00GuildBankStackSplit|r"
addonVars.addonAuthor 			= '|cFFFF00Baertram|r'
addonVars.addonVersion		   	= 0.05
addonVars.addonVersionOptions 	= '0.0.5'

local preventerVars = {}
preventerVars.gLocalizationDone             = false
preventerVars.KeyBindingTexts	            = false
preventerVars.gItemWithdrawFromGuildBank    = false
preventerVars.gSplitDialogIsShown           = false
preventerVars.gSplitWasDone                 = false
preventerVars.gSplitStacks                  = 0
preventerVars.gAfterSplitCounter            = 0
preventerVars.gMultiSplitActive             = false

local settingsVars				= {}
settingsVars.settings       = {}

local localizationVars = {}

local originalVars = {}
originalVars.splitStackDialogCallbackFunction = nil

local globalVars = {}
globalVars.targetSlotIndex  = nil
globalVars.targetName       = ""
globalVars.sourceSlotIndex  = nil
globalVars.sourceName       = ""
globalVars.abortedSplitDialog = false
globalVars.newCreatedStacksSlotIndex = {}

--========================   FUNCTIONS   ===============================================================================

local function AlertMessage(alertMsg)
    if alertMsg and alertMsg ~= "" then
        ZO_Alert(UI_ALERT_CATEGORY_ERROR, SOUNDS.NEGATIVE_CLICK, alertMsg)
    end
end

local function Localization()
    --Was localization already done during keybindings? Then abort here
    if preventerVars.KeyBindingTexts == true and preventerVars.gLocalizationDone == true then return end
    --Is the standard language english set?
    local lang = GetCVar("language.2")
    if lang and lang ~= "" then
        --Check for supported languages
        localizationVars.fco_gbss_loc = fco_gbssloc[lang]
        preventerVars.gLocalizationDone = true
    end
end

local function CheckAndCallSecure(functionName, ...)
    if IsProtectedFunction(functionName) then
        CallSecureProtected(functionName, ...)
    else
        _G[functionName](...)
    end
end

--Called in function  ZO_StackSplit_SplitItem(inventorySlotControl)
local function FCOGuildBankStackSplit_IsSplittableType(slotControl)
    if ZO_GuildBank:IsHidden() or slotControl == nil then return false end
    local splittableTypes =
        {
            [SLOT_TYPE_GUILD_BANK_ITEM] = true, -- added to support guild bank items
            [SLOT_TYPE_BANK_ITEM] = true,
            [SLOT_TYPE_ITEM] = true,
            [SLOT_TYPE_GAMEPAD_INVENTORY_ITEM] = true,
        }
    return splittableTypes[slotControl.slotType]
end

local function FCOGuildBankStackSplit_TryGuildBankDepositItem(sourceBag, sourceSlot)
    local guildId = GetSelectedGuildBankId()
    if(guildId) then
        if(not DoesPlayerHaveGuildPermission(guildId, GUILD_PERMISSION_BANK_DEPOSIT)) then
            ZO_AlertEvent(EVENT_GUILD_BANK_TRANSFER_ERROR, GUILD_BANK_NO_DEPOSIT_PERMISSION)
            return
        end

        if(not DoesGuildHavePrivilege(guildId, GUILD_PRIVILEGE_BANK_DEPOSIT)) then
            ZO_AlertEvent(EVENT_GUILD_BANK_TRANSFER_ERROR, GUILD_BANK_GUILD_TOO_SMALL)
            return
        end

        if(IsItemStolen(sourceBag, sourceSlot)) then
            ZO_AlertEvent(EVENT_GUILD_BANK_TRANSFER_ERROR, GUILD_BANK_NO_DEPOSIT_STOLEN_ITEM)
            return
        end

        TransferToGuildBank(sourceBag, sourceSlot)
        --Reset "split dialog aborted" variable
        globalVars.abortedSplitDialog = false
    end
    ClearCursor()
end

local function FCOGuildBankStackSplit_TryGuildBankWithdrawItem(sourceSlotId)
    local guildId = GetSelectedGuildBankId()
    if(guildId) then
        if(not DoesPlayerHaveGuildPermission(guildId, GUILD_PERMISSION_BANK_WITHDRAW)) then
            ZO_AlertEvent(EVENT_GUILD_BANK_TRANSFER_ERROR, GUILD_BANK_NO_WITHDRAW_PERMISSION)
            return
        end

        if(not DoesBagHaveSpaceFor(BAG_BACKPACK, sourceBag, sourceSlot)) then
            ZO_Alert(UI_ALERT_CATEGORY_ERROR, SOUNDS.NEGATIVE_CLICK, SI_INVENTORY_ERROR_INVENTORY_FULL)
            return
        end

        TransferFromGuildBank(sourceSlotId)
    end
    ClearCursor()
end

--Reset the variables so no split is currently pending/active
local function FCOGuildBankStackSplit_ResetVariables()
    preventerVars.gItemWithdrawFromGuildBank    = false
    preventerVars.gSplitWasDone                 = false
    preventerVars.gAfterSplitCounter            = 0
    preventerVars.gSplitStacks                  = 0
    preventerVars.gMultiSplitActive             = false
    globalVars.sourceName                       = ""
    globalVars.sourceSlotIndex                  = ""
    globalVars.targetName                       = ""
    globalVars.targetSlotIndex                  = ""
end

--Function to check if the split dialog should be called, or if a split was already done
local function FCOGuildBankStackSplit_CheckWhatToDo(slotIndex, currentItemName)
    if slotIndex == nil then return false end
    local inventorySlot = PLAYER_INVENTORY.inventories[INVENTORY_BACKPACK].slots[slotIndex]
    if inventorySlot == nil then return end
    --Is an item withdrawn from the guild bank and we tried to split it?
    if preventerVars.gItemWithdrawFromGuildBank and not preventerVars.gSplitWasDone then
        --Reset variables
        globalVars.targetSlotIndex = nil
        globalVars.targetName = ""
        --d("Split dialog will be called")
        globalVars.targetSlotIndex = slotIndex
        globalVars.targetName = currentItemName
        --Compare the item names now
        if globalVars.targetSlotIndex ~= nil and globalVars.sourceSlotIndex ~= nil
                and globalVars.targetName ~= "" and globalVars.sourceName ~= "" then
            --Compare the item names now to be a bit more sure we got the corretc one :-)
            if (globalVars.sourceName == globalVars.targetName) then
                if inventorySlot.slotControl == nil then
                    --d("!!! [FCOGuildBankStackSplit] inventorySlot.slotControl is nil: FCO3")
                    --The inventory item's slotControl was not build? Why not?
                    --Maybe it gets build if we refresh the list of the own inventory, or just refesh this single item? but how?
                    --For now Move item stack back to guild bank and show error message
                    --Reset the split done/pending variables again
                    FCOGuildBankStackSplit_ResetVariables()
                    --Deposit the taken item again to the guild bank
                    FCOGuildBankStackSplit_TryGuildBankDepositItem(BAG_BACKPACK, slotIndex)
                    --Show alert message
                    if localizationVars.fco_gbss_loc == nil then Localization() end
                    AlertMessage(localizationVars.fco_gbss_loc["error_split_did_not_work_try_again"])
                    return false
                else
                    --d("[FCOGuildBankStackSplit] inventorySlot.slotControl found: FCO2")
                    local inventorySlotControl = inventorySlot.slotControl:GetNamedChild("Button")
                    if inventorySlotControl ~= nil then
                        globalVars.abortedSplitDialog = false
                        preventerVars.gSplitDialogIsShown = true
                        ZO_Dialogs_ShowDialog("SPLIT_STACK", inventorySlotControl)
                    end
                end
            end
        end

        --After a split has taken place the items will be stored in the inventory and this event here will tell you for each split
        --stack the new slotIndex in the inventory. You can use this to deposit the split items on your guild bank again, afterwards
    elseif preventerVars.gSplitWasDone and not preventerVars.gMultiSplitActive then
        --d("Split was done")
        if globalVars.targetName ~= "" and currentItemName ~= "" and currentItemName ~= nil and globalVars.targetName == currentItemName then
            --d("Name of split item is equal to current new item")
            --In variable preventerVars.gSplitStacks you will find the number of created stacks. for each stack the new slotIndex needs to be collected here
            if preventerVars.gAfterSplitCounter == nil or preventerVars.gAfterSplitCounter == 0 then
                preventerVars.gAfterSplitCounter = 1
                globalVars.newCreatedStacksSlotIndex = {}
            end
            --d("Split was done with " .. preventerVars.gSplitStacks .. " stacks, SlotIndex: " .. slotIndex)
            --Collect the slotIndex
            globalVars.newCreatedStacksSlotIndex[preventerVars.gAfterSplitCounter] = slotIndex
            --Check if we have collected each new created stack (+1 because the split stacks will not contain the rest of the items)
            local maxNewInvSlots = 0
            if preventerVars.gSplitStacks == 1 then
                maxNewInvSlots = 2
            else
                maxNewInvSlots = (preventerVars.gSplitStacks*2)
            end
            --d("Counter: " .. preventerVars.gAfterSplitCounter .. " / MaxNewInvSlots: " .. maxNewInvSlots)
            if preventerVars.gAfterSplitCounter == maxNewInvSlots then
                --Move the base stack, not the new created one, back to the guild bank
                FCOGuildBankStackSplit_TryGuildBankDepositItem(BAG_BACKPACK, globalVars.newCreatedStacksSlotIndex[maxNewInvSlots])
                --Reset the split done/pending variables again
                FCOGuildBankStackSplit_ResetVariables()
            end
            --Increase the counter by 1
            preventerVars.gAfterSplitCounter = preventerVars.gAfterSplitCounter + 1
        end
    end

end

--An inventory slot was updated. Will be called BEFORE event ITEM REMOVED FROM GUILD BANK applies
local function FCOGuildBankStackSplit_InventorySingleSlotUpdated(eventCode, bagId, slotIndex, isNewItem, itemSoundCategory, updateReason)
--d("[InvSlotUpdate] " .. slotIndex .. ", isNewItem: " .. tostring(isNewItem) .. ", updateReason: " .. tostring(updateReason).."/"..INVENTORY_UPDATE_REASON_DEFAULT)
    --Did we get tot his event because we triggered it, or any other addon triggered it (like Roomba?)
    if not preventerVars.gItemWithdrawFromGuildBank and not preventerVars.gSplitWasDone then return end
    --Are we showing the guild bank and is the update reason a default reason and not due to dye, duration etc.
    if   ZO_GuildBank:IsHidden() or updateReason ~= INVENTORY_UPDATE_REASON_DEFAULT or isNewItem
      or preventerVars.gSplitDialogIsShown then return false end
    --Abort here if we are arrested by a guard (thief system) as it will scann our inventory for stolen items and we don't need to
    --scan it with our functions too at this case
    if IsUnderArrest() then return end
    --Check if item in slot is still there
    if GetItemType(bagId, slotIndex) == ITEMTYPE_NONE then return end

    --Is the current item's name equal to the last split name?
    local currentItemName = ""
    local inventorySlot = PLAYER_INVENTORY.inventories[INVENTORY_BACKPACK].slots[slotIndex]
    if inventorySlot ~= nil then
        currentItemName = inventorySlot.name
    end
    if currentItemName == nil or currentItemName == "" then return false end
--d("Current item name: " .. currentItemName)

    -- Check if a split was done and if the current item is belongng to this split (comparing item names).
    -- If not, reset the split variables and abort this function with false to call the original event callback function afterwards
    if   (globalVars.abortedSplitDialog
      or (preventerVars.gSplitWasDone and (globalVars.targetName == "" or currentItemName == "" or globalVars.targetName ~= currentItemName)) ) then
--d(">>> Reset split variables now and abort")
        FCOGuildBankStackSplit_ResetVariables()
        return false
    end
    --Delayed call to check if split dialog should be shown or if split was already done
    --so the slotControl is build up correctly
    zo_callLater(function()  FCOGuildBankStackSplit_CheckWhatToDo(slotIndex, currentItemName) end, settingsVars.settings.splitPopupDelay or 150)
    --Execute the normal inventory single slot update now to build the slot control
    return false
end

--Global function to start the split of a stack
function FCOGuildBankStackSplit_SplitStackNow(pControl, pBagId, pSlotIndex)
    if pControl == nil or pBagId == nil or pSlotIndex == nil then return end
    --Set global variable for "item is transferred to local inventory" to true
    preventerVars.gItemWithdrawFromGuildBank = true
    --Remember the source slotIndex of the item
    globalVars.sourceSlotIndex = pSlotIndex
    --Remember the name of the item
    local guildBankSlot = PLAYER_INVENTORY.inventories[INVENTORY_GUILD_BANK].slots[pSlotIndex]
    if guildBankSlot == nil then return false end
    globalVars.sourceName = guildBankSlot.name
    --Try to move the item to the local inventory now
    FCOGuildBankStackSplit_TryGuildBankWithdrawItem(pSlotIndex)
end

local function FCOGuildBankStackSplit_command_handler(args)
    --Parse the arguments string
    local options = {}
    local searchResult = { string.match(args, "^(%S*)%s*(.-)$") }
    for i,v in pairs(searchResult) do
        if (v ~= nil and v ~= "") then
            options[i] = string.lower(v)
        end
    end

    --No chat options
    if options == nil or #options == 0 or options[1] == "" then
        d(localizationVars.fco_gbss_loc["chat_command_help"])
        d(localizationVars.fco_gbss_loc["chat_command_commands_headline"])
        d(localizationVars.fco_gbss_loc["chat_command_commands_delay"])
    end

    local function ShowCurrentDelay()
        d(localizationVars.fco_gbss_loc["chat_command_current_delay"] .. " " .. settingsVars.settings.splitPopupDelay .. " (" .. localizationVars.fco_gbss_loc["chat_command_delay_min"] .. ": " .. settingsVars.settings.splitPopupDelayMin.. " / " .. localizationVars.fco_gbss_loc["chat_command_delay_max"] .. ": " .. settingsVars.settings.splitPopupDelayMax .. ")")
    end

    --Delay?
    if(options[1] == "delay") then
        --Show current delay?
        if options[2] == nil or options[2] == "" then
            ShowCurrentDelay()
        elseif options[2] ~= nil and options[2] ~= "" then
            local intDelay = tonumber(options[2])
            if type(intDelay) == "number" then
				if intDelay < settingsVars.settings.splitPopupDelayMin then intDelay = settingsVars.settings.splitPopupDelayMin end
				if intDelay > settingsVars.settings.splitPopupDelayMax then intDelay = settingsVars.settings.splitPopupDelayMax end
                settingsVars.settings.splitPopupDelay = intDelay
                ShowCurrentDelay()
            end
        end
    end
end

local function FCOGuildBankStackSplit_ChatCommands()
    --Register the slash commands
    SLASH_COMMANDS["/fcoguildbankstacksplit"] = FCOGuildBankStackSplit_command_handler
    SLASH_COMMANDS["/fcogbss"] 		          = FCOGuildBankStackSplit_command_handler
end

local function FCOGuildBankStackSplit_Loaded(eventCode, addOnName)
    if(addOnName ~= addonVars.gAddonName) then
        return
    end

    --Load the saved variables
    --Pre-set the deafult values
    settingsVars.defaults = {
        splitPopupDelay         = 150,
        splitPopupDelayMin      = 0,
        splitPopupDelayMax      = 5000,
    }

    --=========== BEGIN - SAVED VARIABLES ==========================================
    --Use the current addon version to read the settingsVars.settings now
    settingsVars.settings = ZO_SavedVars:NewAccountWide(addonVars.gAddonName .. "_Settings", addonVars.addonVersion, "Settings", settingsVars.defaults)
    --=========== END - SAVED VARIABLES ============================================

    -- Set Localization
    preventerVars.KeyBindingTexts = false
    Localization()

    --Activate the chat commands
    FCOGuildBankStackSplit_ChatCommands()
end

--==============================================================================
--			Right-click /context menu functions
--==============================================================================
local function FCOGuildBankStackSplit_AddContextMenuEntry(control)
    if control == nil then return false end
    local slotIndex = control.slotIndex
    if slotIndex == nil then return false end
    local slotType = ZO_InventorySlot_GetType(control)
    local slot = nil
    if(slotType == SLOT_TYPE_GUILD_BANK_ITEM) then
        slot = PLAYER_INVENTORY.inventories[INVENTORY_GUILD_BANK].slots[slotIndex]
    elseif(slotType == SLOT_TYPE_ITEM) then
        slot = PLAYER_INVENTORY.inventories[INVENTORY_BACKPACK].slots[slotIndex]
    elseif(slotType == SLOT_TYPE_BANK_ITEM) then
        slot = PLAYER_INVENTORY.inventories[INVENTORY_BANK].slots[slotIndex]
    end
    if slot == nil then return false end
    local bagId = control.bagId
    if bagId == nil or slotIndex == nil then return false end
    if(slot.locked) then
        ZO_Alert(UI_ALERT_CATEGORY_ERROR, SOUNDS.NEGATIVE_CLICK, GetString(SI_ERROR_ITEM_LOCKED))
        return false
    end
    local stackSize = GetSlotStackSize(bagId, slotIndex)
    local isSplittable = FCOGuildBankStackSplit_IsSplittableType(control)
    if(stackSize <= 1 or isSplittable == false) then
        return false
    end
    --Add the "Split" context menu entry now
    AddMenuItem(GetString(SI_ITEM_ACTION_SPLIT_STACK), function()
        FCOGuildBankStackSplit_SplitStackNow(control, bagId, slotIndex)
    end, MENU_ADD_OPTION_LABEL)
    ShowMenu(control)
end

--Player is activated in the game
local function FCOGuildBankStackSplit_PlayerActivated(event)
    EVENT_MANAGER:UnregisterForEvent(addonVars.gAddonName, event)

    -- Hook functions for the inventory/store contextmenus
    ZO_PreHook("ZO_InventorySlot_ShowContextMenu", function(rowControl)
        if not ZO_GuildBank:IsHidden() then
            zo_callLater(function() FCOGuildBankStackSplit_AddContextMenuEntry(rowControl) end, 50)
        end
    end)

    --PreHook the ESO dialog button "Accept" callback function of the "split stack" dialog
    local dialog = ESO_Dialogs["SPLIT_STACK"]
    --Backup the split dialog callback function of button 1
    --originalVars.splitStackDialogCallbackFunction = dialog.buttons[1].callback

    --Pre-Hook the callback function for the split dialog decline button
    ZO_PreHookHandler(ZO_StackSplit, "OnHide", function()
        preventerVars.gSplitDialogIsShown = false
        preventerVars.gItemWithdrawFromGuildBank = false
        --is the guild bank shown?
        if ZO_GuildBank:IsHidden() then return false end
        if not preventerVars.gSplitWasDone then
            globalVars.abortedSplitDialog = true
            --Reset the new created stacks variable
            preventerVars.gSplitStacks = 0
            --Reset the counter for the event inventory single slot updated to 0
            preventerVars.gAfterSplitCounter = 0
            --Set the flag that the multisplit is deativated
            preventerVars.gMultiSplitActive = false
            --Deposit the taken item again to the guild bank
            FCOGuildBankStackSplit_TryGuildBankDepositItem(BAG_BACKPACK, globalVars.targetSlotIndex)
        end
        --Reset the global variables, except for the name of the split item, as this is used to check the
        --new stacks
        globalVars.sourceSlotIndex = nil
        globalVars.sourceName = ""
        globalVars.targetSlotIndex = nil
    end)


    --Pre-Hook the callback function for the split dialog decline button
    ZO_PreHook(dialog.buttons[2].control, "callback", function(control)
        --is the guild bank shown?
        if ZO_GuildBank:IsHidden() or control == nil then return false end
        --Reset the new created stacks variable
        preventerVars.gSplitStacks = 0
        --Reset the counter for the event inventory single slot updated to 0
        preventerVars.gAfterSplitCounter = 0
        --Reset: A split was done
        preventerVars.gSplitWasDone = false
        --Set the flag that the multisplit is deativated
        preventerVars.gMultiSplitActive = false
    end)

    --Pre-Hook the callback function for the split dialog accept button
    ZO_PreHook(dialog.buttons[1], "callback", function(control)
        --is the guild bank shown?
        if ZO_GuildBank:IsHidden() or control == nil then return false end
        --Reset: A split was done
        preventerVars.gSplitWasDone = false
        --Set the flag that the multisplit is deativated
        preventerVars.gMultiSplitActive = false
        local bagId, slotIndex = ZO_Inventory_GetBagAndIndex(control.slotControl)
        if bagId == nil or slotIndex == nil then return true end
        local it = nil
        local emptySlotIndex
        local numStacks = 1
        --local numStacksRest = 0
        local freeSlots = {}
        --Is Harven's stack split slider addon active?
        local checkbox = WINDOW_MANAGER:GetControlByName("HarvensStackSplitCheckbox", "")
        local cbChecked = false
        if checkbox ~= nil then cbChecked = ZO_CheckButton_IsChecked(checkbox) end
        if checkbox ~= nil and cbChecked then
            --Set the flag that the multisplit is ativated
            preventerVars.gMultiSplitActive = true
            --numStacksRest = control.stackSize % control.spinner:GetValue()
            numStacks = math.floor(control.stackSize/control.spinner:GetValue())
            for i=0, GetBagSize(bagId)-1 do
                if GetItemTotalCount(bagId, i) == 0 then
                    table.insert(freeSlots, i)
                end
            end
        else
            emptySlotIndex = FindFirstEmptySlotInBag(bagId)
        end
        --Reset the new created stacks variable
        preventerVars.gSplitStacks = 0
        for i=1, numStacks do
            CheckAndCallSecure("PickupInventoryItem", bagId, slotIndex, control.spinner:GetValue())
            if checkbox ~= nil and cbChecked then
                it, emptySlotIndex = next(freeSlots, it)
            end
            if emptySlotIndex ~= nil then
                CheckAndCallSecure("PlaceInInventory", bagId, emptySlotIndex)
                --Increase the new created stacks variable by 1 for each new stack
                --if ( cbChecked and i == numStacks and numStacksRest == 0 ) then
                    --In this case the multisplit is the same like doing a normal split and thus the split stacks must not be increased at the last stack
                --else
                    preventerVars.gSplitStacks = preventerVars.gSplitStacks + 1
                --end
            else
                local errorStringId = (targetBag == BAG_BACKPACK) and SI_INVENTORY_ERROR_INVENTORY_FULL --or SI_INVENTORY_ERROR_BANK_FULL
                ZO_Alert(UI_ALERT_CATEGORY_ERROR, SOUNDS.NEGATIVE_CLICK, errorStringId)
                ClearCursor()
                break
            end
            ClearCursor()
        end
        --Reset the counter for the event inventory single slot updated to 0 so the event knows there was done a new split to stacks
        preventerVars.gAfterSplitCounter = 0
--[[
        --Is there a rest after the split into several stacks has taken place by the checkbox?
        if numStacksRest > 0 then
            --Increase the variable for the stacks by 1 as there is one stack left with some items
            preventerVars.gSplitStacks = preventerVars.gSplitStacks + 1
        end
]]
        --A split was done
        preventerVars.gSplitWasDone = true
        globalVars.abortedSplitDialog = false
        --Return true if everything was handled already in this function. False if the normal function should be called after this one here
        return true
    end)
end

local function FCOGuildBankStackSplit_Initialized()
    EVENT_MANAGER:RegisterForEvent(addonVars.gAddonName, EVENT_ADD_ON_LOADED, FCOGuildBankStackSplit_Loaded)
    EVENT_MANAGER:RegisterForEvent(addonVars.gAddonName, EVENT_PLAYER_ACTIVATED, FCOGuildBankStackSplit_PlayerActivated)
    EVENT_MANAGER:RegisterForEvent(addonVars.gAddonName, EVENT_INVENTORY_SINGLE_SLOT_UPDATE, FCOGuildBankStackSplit_InventorySingleSlotUpdated)
end

--Global function to get text for the keybindings etc.
function FCO_GetGBSSLocText(textName, isKeybindingText)
    isKeybindingText = isKeybindingText or false

    preventerVars.KeyBindingTexts = isKeybindingText

    --Do the localization now
    Localization()

    if textName == nil or localizationVars.fco_gbss_loc == nil or localizationVars.fco_gbss_loc[textName] == nil then return "" end
    return localizationVars.fco_gbss_loc[textName]
end


-- Call the start function for this addon
FCOGuildBankStackSplit_Initialized()
